Index: src/core/SkBitmapCache.h |
diff --git a/src/core/SkBitmapCache.h b/src/core/SkBitmapCache.h |
index c75894208072a100362429199be1b6e047045bac..3e541eed2c57f7c2d54bd5142fa72d7ae9c27e26 100644 |
--- a/src/core/SkBitmapCache.h |
+++ b/src/core/SkBitmapCache.h |
@@ -22,7 +22,7 @@ class SkBitmapCache { |
public: |
/** |
* Use this allocator for bitmaps, so they can use ashmem when available. |
* Returns NULL if the ResourceCache has not been initialized with a DiscardableFactory. |
*/ |
static SkBitmap::Allocator* GetAllocator(); |
@@ -31,37 +31,37 @@ public: |
* result will be set to the matching bitmap with its pixels already locked. |
*/ |
static bool Find(const SkBitmap& src, SkScalar invScaleX, SkScalar invScaleY, SkBitmap* result, |
- SkResourceCache* localCache = NULL); |
+ SkResourceCache* localCache = nullptr); |
/* |
* result must be marked isImmutable() |
*/ |
static void Add(const SkBitmap& src, SkScalar invScaleX, SkScalar invScaleY, |
- const SkBitmap& result, SkResourceCache* localCache = NULL); |
+ const SkBitmap& result, SkResourceCache* localCache = nullptr); |
/** |
* Search based on the bitmap's genID and subset. If found, returns true and |
* result will be set to the matching bitmap with its pixels already locked. |
*/ |
static bool Find(uint32_t genID, const SkIRect& subset, SkBitmap* result, |
- SkResourceCache* localCache = NULL); |
+ SkResourceCache* localCache = nullptr); |
/** |
* The width and the height of the provided subset must be the same as the result bitmap ones. |
* result must be marked isImmutable() |
*/ |
static bool Add(SkPixelRef*, const SkIRect& subset, const SkBitmap& result, |
- SkResourceCache* localCache = NULL); |
+ SkResourceCache* localCache = nullptr); |
- static bool Find(uint32_t genID, SkBitmap* result, SkResourceCache* localCache = NULL); |
+ static bool Find(uint32_t genID, SkBitmap* result, SkResourceCache* localCache = nullptr); |
// todo: eliminate the need to specify ID, since it should == the bitmap's |
- static void Add(uint32_t genID, const SkBitmap&, SkResourceCache* localCache = NULL); |
+ static void Add(uint32_t genID, const SkBitmap&, SkResourceCache* localCache = nullptr); |
}; |
class SkMipMapCache { |
public: |
- static const SkMipMap* FindAndRef(const SkBitmap& src, SkResourceCache* localCache = NULL); |
- static const SkMipMap* AddAndRef(const SkBitmap& src, SkResourceCache* localCache = NULL); |
+ static const SkMipMap* FindAndRef(const SkBitmap& src, SkResourceCache* localCache = nullptr); |
+ static const SkMipMap* AddAndRef(const SkBitmap& src, SkResourceCache* localCache = nullptr); |
}; |
#endif |
@@ -22,7 +22,7 @@ class SkBitmapCache { |
/** |
* Use this allocator for bitmaps, so they can use ashmem when available. |
- * Returns NULL if the ResourceCache has not been initialized with a DiscardableFactory. |
+ * Returns nullptr if the ResourceCache has not been initialized with a DiscardableFactory. |
*/ |
static SkBitmap::Allocator* GetAllocator(); |